@@ -1,13 +1,16 @@
 var class_salesforce_soap_client_1_1_salesforce_soap_connection =
 [
+    [ "checkOpts", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#a523a0c0a5333f4ce88664b0ccdd61ac5", null ],
+    [ "constructor", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#a7f31be37316bc90f35923bd652129712", null ],
     [ "constructor", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#aa94f4c9b2cdb23785786d262b09c8526", null ],
-    [ "getConnectionSchemeInfoImpl", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#ae7b7bc91babf9e4282894de3531798b2", null ],
+    [ "getConnectionSchemeInfoImpl", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#a9c303204c6aa1ac035626120c6661ed9", null ],
     [ "getImpl", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#ab6f1c9ecc8dd8ec653d44da911c87bd0", null ],
-    [ "getRuntimeOptions", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#a905dc32a85c37544a3501d872ee18225", null ],
+    [ "getRuntimeOptions", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#af0621db8f5a00e452342771b891e2dac", null ],
     [ "getType", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#ad0161e2cb35ce7cc3a393ce0b9d437f6", null ],
     [ "getWebService", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#ace7cf9462af19d72d2532f7cb78f0f56", null ],
     [ "getWsdl", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#a28b9047165cf1b70b2d18216ba11383b", null ],
     [ "getWsdlFromCache", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#a574c1bbb534790af1db933203329b752", null ],
+    [ "supportsPollingApi", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#af34ad0c259cb8b49ffb7d126b1737434", null ],
     [ "cache", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#a646f89e95047f21e132a65465881c05a", null ],
     [ "ConnectionScheme", "class_salesforce_soap_client_1_1_salesforce_soap_connection.html#abbc4cbbe561be2839dcdb78a657f541d", null ]
 ];
\ No newline at end of file
