@@ -1,12 +1,11 @@
 var indexSectionsWithContent =
 {
-  0: "abcdefghilmnopqrstuvwx",
-  1: "abcfimnopswx",
-  2: "mqsw",
-  3: "abcdefghilmnoprstvwx",
-  4: "abcdefhimnoprstuvwx",
-  5: "x",
-  6: "s"
+  0: "01234acdefgilmnprstv",
+  1: "s",
+  2: "s",
+  3: "cdglmps",
+  4: "acfr",
+  5: "ms"
 };
 
 var indexSectionNames =
@@ -16,8 +15,7 @@ var indexSectionNames =
   2: "namespaces",
   3: "functions",
   4: "variables",
-  5: "groups",
-  6: "pages"
+  5: "pages"
 };
 
 var indexSectionLabels =
@@ -27,7 +25,6 @@ var indexSectionLabels =
   2: "Namespaces",
   3: "Functions",
   4: "Variables",
-  5: "Modules",
-  6: "Pages"
+  5: "Pages"
 };
 
