@@ -3,6 +3,7 @@ var annotated_dup =
     [ "SoapDataProvider", "namespace_soap_data_provider.html", [
       [ "SoapDataProvider", "class_soap_data_provider_1_1_soap_data_provider.html", "class_soap_data_provider_1_1_soap_data_provider" ],
       [ "SoapDataProviderBase", "class_soap_data_provider_1_1_soap_data_provider_base.html", "class_soap_data_provider_1_1_soap_data_provider_base" ],
-      [ "SoapDataProviderFactory", "class_soap_data_provider_1_1_soap_data_provider_factory.html", "class_soap_data_provider_1_1_soap_data_provider_factory" ]
+      [ "SoapDataProviderFactory", "class_soap_data_provider_1_1_soap_data_provider_factory.html", "class_soap_data_provider_1_1_soap_data_provider_factory" ],
+      [ "SoapRequestDataProvider", "class_soap_data_provider_1_1_soap_request_data_provider.html", "class_soap_data_provider_1_1_soap_request_data_provider" ]
     ] ]
 ];
\ No newline at end of file
