@@ -3,5 +3,6 @@ var namespace_soap_data_provider =
     [ "SoapDataProvider", "class_soap_data_provider_1_1_soap_data_provider.html", "class_soap_data_provider_1_1_soap_data_provider" ],
     [ "SoapDataProviderBase", "class_soap_data_provider_1_1_soap_data_provider_base.html", "class_soap_data_provider_1_1_soap_data_provider_base" ],
     [ "SoapDataProviderFactory", "class_soap_data_provider_1_1_soap_data_provider_factory.html", "class_soap_data_provider_1_1_soap_data_provider_factory" ],
-    [ "SoapRequestDataProvider", "class_soap_data_provider_1_1_soap_request_data_provider.html", "class_soap_data_provider_1_1_soap_request_data_provider" ]
+    [ "SoapRequestDataProvider", "class_soap_data_provider_1_1_soap_request_data_provider.html", "class_soap_data_provider_1_1_soap_request_data_provider" ],
+    [ "AppName", "namespace_soap_data_provider.html#a6c0670352cf3579dece56d5114c0df7f", null ]
 ];
\ No newline at end of file
