@@ -6,7 +6,7 @@ var indexSectionsWithContent =
   3: "abcdefghilmnoprstvx",
   4: "ehmnvx",
   5: "x",
-  6: "sx"
+  6: "s"
 };
 
 var indexSectionNames =
