@@ -25,28 +25,7 @@
 var NAVTREE =
 [
   [ "Qore WSDL Module Reference", "index.html", [
-    [ "WSDL Module", "index.html", [
-      [ "Introduction to the WSDL Module", "index.html#wsdlintro", null ],
-      [ "WSDL Module Release Notes", "index.html#wsdlrelnotes", [
-        [ "WSDL v0.5.4", "index.html#wsdl_0_5_4", null ],
-        [ "WSDL v0.5.3", "index.html#wsdl_0_5_3", null ],
-        [ "WSDL v0.5.2", "index.html#wsdl_0_5_2", null ],
-        [ "WSDL v0.5.1", "index.html#wsdl_0_5_1", null ],
-        [ "WSDL v0.5", "index.html#wsdl_0_5", null ],
-        [ "WSDL v0.4", "index.html#wsdl_0_4", null ],
-        [ "WSDL v0.3.8", "index.html#wsdl_0_3_8", null ],
-        [ "WSDL v0.3.7", "index.html#wsdl_0_3_7", null ],
-        [ "WSDL v0.3.6", "index.html#wsdl_0_3_6", null ],
-        [ "WSDL v0.3.5.1", "index.html#wsdl_0_3_5_1", null ],
-        [ "WSDL v0.3.5", "index.html#wsdl_0_3_5", null ],
-        [ "WSDL v0.3.4", "index.html#wsdl_0_3_4", null ],
-        [ "WSDL v0.3.3", "index.html#wsdl_0_3_3", null ],
-        [ "WSDL v0.3.2", "index.html#wsdl_0_3_2", null ],
-        [ "WSDL v0.3.1", "index.html#wsdl_0_3_1", null ],
-        [ "WSDL v0.3.0", "index.html#wsdl_0_3_0", null ],
-        [ "WSDL v0.2.0", "index.html#wsdl_0_2_0", null ]
-      ] ]
-    ] ],
+    [ "WSDL Module", "index.html", "index" ],
     [ "Namespaces", "namespaces.html", [
       [ "Namespace List", "namespaces.html", "namespaces_dup" ],
       [ "Namespace Members", "namespacemembers.html", [
@@ -70,7 +49,8 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"annotated.html"
+"annotated.html",
+"class_w_s_d_l_1_1_web_service.html#a49f1077da1bbfa939751a69ce9192290"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
