@@ -1,12 +1,11 @@
 var indexSectionsWithContent =
 {
-  0: "abcdefghilmnopqrstuvwx",
-  1: "abcdfimnopswx",
-  2: "mqw",
-  3: "abcdefghilmnoprstvwx",
-  4: "abcdefhilmnoprstuvwx",
-  5: "x",
-  6: "w"
+  0: "0abcdefghilmnprsvw",
+  1: "adfiw",
+  2: "w",
+  3: "cdghilmprsv",
+  4: "abdilmnprv",
+  5: "mw"
 };
 
 var indexSectionNames =
@@ -16,8 +15,7 @@ var indexSectionNames =
   2: "namespaces",
   3: "functions",
   4: "variables",
-  5: "groups",
-  6: "pages"
+  5: "pages"
 };
 
 var indexSectionLabels =
@@ -27,7 +25,6 @@ var indexSectionLabels =
   2: "Namespaces",
   3: "Functions",
   4: "Variables",
-  5: "Modules",
-  6: "Pages"
+  5: "Pages"
 };
 
