@@ -1,12 +1,11 @@
 var indexSectionsWithContent =
 {
-  0: "abcdefghilmnopqrstvx",
-  1: "afimsx",
-  2: "mqx",
-  3: "abcdefghilmnoprstvx",
-  4: "ehmnx",
-  5: "x",
-  6: "x"
+  0: "01234cghimrtvx",
+  1: "x",
+  2: "x",
+  3: "cg",
+  4: "c",
+  5: "mx"
 };
 
 var indexSectionNames =
@@ -16,8 +15,7 @@ var indexSectionNames =
   2: "namespaces",
   3: "functions",
   4: "variables",
-  5: "groups",
-  6: "pages"
+  5: "pages"
 };
 
 var indexSectionLabels =
@@ -27,7 +25,6 @@ var indexSectionLabels =
   2: "Namespaces",
   3: "Functions",
   4: "Variables",
-  5: "Modules",
-  6: "Pages"
+  5: "Pages"
 };
 
