@@ -1,11 +1,11 @@
 var indexSectionsWithContent =
 {
-  0: "acgisvx",
+  0: "acegimstuvx",
   1: "x",
   2: "x",
   3: "acgs",
   4: "ivx",
-  5: "x"
+  5: "mx"
 };
 
 var indexSectionNames =
