@@ -37,7 +37,7 @@ hashdecl PropPatchActionInfo {
 }
 
 //! Abstract WebDavHandler interface class
-class AbstractWebDavHandler : public HttpServer::AbstractHttpRequestHandler {
+class AbstractWebDavHandler : public HttpServer::AbstractHttpRequestHandler  {
 
 public:
         //! A hash of all supported WebDavHandler methods mapped to method names
@@ -73,37 +73,36 @@ protected:
 public:
 
     //! Creates the object with an empty logger and an in-memory property handler
-/** @param auth the authentication object to use to authenticate connections
+    /** @param auth the authentication object to use to authenticate connections
     */
     constructor(__7_ AbstractAuthenticator auth) ;
 
 
     //! Creates the object with the given argument and an in-memory property handler
-/** @param auth the authentication object to use to authenticate connections
+    /** @param auth the authentication object to use to authenticate connections
         @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
-    constructor(__7_ AbstractAuthenticator auth, string virtual_relative_path_base) 
- ;
+    constructor(__7_ AbstractAuthenticator auth, string virtual_relative_path_base) ;
 
 
     //! Creates the object with the given arguments
-/** @param auth the authentication object to use to authenticate connections
+    /** @param auth the authentication object to use to authenticate connections
         @param property_handler to handle properties
         @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
-constructor(__7_ AbstractAuthenticator auth, AbstractWebDavPropertyHandler property_handler, string virtual_relative_path_base = '/') ;
+    constructor(__7_ AbstractAuthenticator auth, AbstractWebDavPropertyHandler property_handler, string virtual_relative_path_base = '/') ;
 
 
     //! Creates the object with the given arguments
-/** @param auth the authentication object to use to authenticate connections
+    /** @param auth the authentication object to use to authenticate connections
         @param logger the logger
         @param property_handler to handle properties
         @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
-constructor(__7_ AbstractAuthenticator auth, Logger logger, AbstractWebDavPropertyHandler property_handler = new InMemoryWebDavPropertyHandler(), string virtual_relative_path_base = '/') ;
+    constructor(__7_ AbstractAuthenticator auth, Logger logger, AbstractWebDavPropertyHandler property_handler = new InMemoryWebDavPropertyHandler(), string virtual_relative_path_base = '/') ;
 
 
     //! Returnd a list of WebDavHandler methods
@@ -115,11 +114,11 @@ constructor(__7_ AbstractAuthenticator auth, Logger logger, AbstractWebDavProper
 
 
     //! Handles HTTP/WebDavHandler requests and returns the response
-hash<HttpResponseInfo> handleRequest(HttpListenerInterface listener, Socket s, hash<auto> cx, hash<auto> hdr, *data body);
+    hash<HttpResponseInfo> handleRequest(HttpListenerInterface listener, Socket s, hash<auto> cx, hash<auto> hdr, *data body);
 
 
     //! Returns a relative path from an absolute path
-/** @param raw_path the rar path to process
+    /** @param raw_path the rar path to process
 
         @return a relative path generated by stripping any virtual base path (set in the constructor) from the
         argument
@@ -153,12 +152,12 @@ hash<HttpResponseInfo> handleRequest(HttpListenerInterface listener, Socket s, h
 
     //! Common constructor code
 protected:
- init(Logger logger, AbstractWebDavPropertyHandler property_handler, string virtual_relative_path_base = '/');
+     init(Logger logger, AbstractWebDavPropertyHandler property_handler, string virtual_relative_path_base = '/');
 public:
 
 
     //! Converts a request path to a normalized real path on the filesystem in the root WebDavHandler directory
-/** @throw WEBDAVHANDLER-FORBIDDEN if the path is not valid
+    /** @throw WEBDAVHANDLER-FORBIDDEN if the path is not valid
     */
 protected:
      string getRealPath(string raw_path);
@@ -166,7 +165,7 @@ public:
 
 
     //! Checks if the request is authorized; if not, this method must return a value
-/** Override this in a subclass to implement authorization controls
+    /** Override this in a subclass to implement authorization controls
     */
 protected:
      __7_ hash<HttpResponseInfo> checkAuth(string method, hash<auto> cx, hash<auto> hdr, __7_ data body);
@@ -193,7 +192,7 @@ public:
 
     //! Returns a hash that can be serialized to an XML string for a PROPFIND request
 protected:
- hash<auto> preparePropFindXmlResponse(string local_path, string href, bool is_collection, hash<auto> base_props, bool all_props = False, *hash<string, hash<string, bool>> additional_props);
+     hash<auto> preparePropFindXmlResponse(string local_path, string href, bool is_collection, hash<auto> base_props, bool all_props = False, *hash<string, hash<string, bool>> additional_props);
 public:
 
 
@@ -203,7 +202,7 @@ public:
 
 
     //! Returns a status message for the given HTTP response code
-/** @throw RESPONSE-ERROR the code is unknown
+    /** @throw RESPONSE-ERROR the code is unknown
     */
 protected:
      string getStatusMessage(softstring http_code);
@@ -211,7 +210,7 @@ public:
 
 
     //! Handles a WebDavHandler OPTIONS request
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -251,7 +250,7 @@ public:
 
 
     //! Handles HTTP GET requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -291,7 +290,7 @@ public:
 
 
     //! Handles HTTP HEAD requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -331,7 +330,7 @@ public:
 
 
     //! Handles HTTP POST requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -371,7 +370,7 @@ public:
 
 
     //! Handles HTTP PUT requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -411,7 +410,7 @@ public:
 
 
     //! Handles HTTP DELETE requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -451,7 +450,7 @@ public:
 
 
     //! Handles WebDavHandler COPY requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -491,7 +490,7 @@ public:
 
 
     //! Handles WebDavHandler MOVE requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -531,7 +530,7 @@ public:
 
 
     //! Handles WebDavHandler LOCK requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -571,7 +570,7 @@ public:
 
 
     //! Handles WebDavHandler UNLOCK requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -611,7 +610,7 @@ public:
 
 
     //! Handles WebDavHandler MKCOL requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -651,7 +650,7 @@ public:
 
 
     //! Handles WebDavHandler PROPFIND requests for WebDavHandler resources; reetrieves properties from WebDavHandler resources
-/**
+    /**
         @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
@@ -692,7 +691,7 @@ public:
 
 
     //! Handles WebDavHandler PROPPATCH requests for WebDavHandler resources; sets or removes properties on WebDavHandler resources
-/**
+    /**
         @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
@@ -733,19 +732,19 @@ public:
 
 
     //! This method is called with informational log messages
-/** 
+    /** 
     */
     logInfo(string fmt);
 
 
     //! This method is called with error log messages
-/** 
+    /** 
     */
     logError(string fmt);
 
 
     //! This method is called with debug log messages
-/** 
+    /** 
     */
     logDebug(string fmt);
 
@@ -757,7 +756,7 @@ public:
 
 
     //! Handles an HTTP/WebDavHandler OPTIONS request
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -797,7 +796,7 @@ public:
 
 
     //! Handles HTTP GET requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -836,7 +835,7 @@ protected:
 public:
 
     //! Handles HTTP HEAD requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -875,7 +874,7 @@ protected:
 public:
 
     //! Handles HTTP POST requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -914,7 +913,7 @@ protected:
 public:
 
     //! Handles HTTP PUT requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -953,7 +952,7 @@ protected:
 public:
 
     //! Handles HTTP DELETE requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -992,7 +991,7 @@ protected:
 public:
 
     //! Handles WebDavHandler COPY requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -1031,7 +1030,7 @@ protected:
 public:
 
     //! Handles WebDavHandler MOVE requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -1070,7 +1069,7 @@ protected:
 public:
 
     //! Handles WebDavHandler LOCK requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -1109,7 +1108,7 @@ protected:
 public:
 
     //! Handles WebDavHandler UNLOCK requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -1148,7 +1147,7 @@ protected:
 public:
 
     //! Handles WebDavHandler MKCOL requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -1187,7 +1186,7 @@ protected:
 public:
 
     //! Handles WebDavHandler PROPFIND requests for WebDavHandler resources; reetrieves properties from WebDavHandler resources
-/**
+    /**
         @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
@@ -1227,7 +1226,7 @@ protected:
 public:
 
     //! Internal method for handling PROPPATCH requests
-/** @param href the href for the response
+    /** @param href the href for the response
         @param cx the HTTP call context
         @param hdr as hash HTTP headers
         @param request_xml the parsed XML in the request
@@ -1237,8 +1236,12 @@ public:
 
         @throw WEBDAVHANDLER-ERROR an error occured
     */
+protected:
+     abstract __7_ hash<string, hash<string, hash<string, bool>>> handleProppatchImpl(reference<string> href, hash<auto> cx, hash<auto> hdr, *hash<auto> request_xml, *list<hash<PropPatchActionInfo>> actions);
+public:
+
 private:
- abstract __7_ hash<string, hash<string, hash<string, bool>>> handleProppatchImpl(reference<string> href, hash<auto> cx, hash<auto> hdr, *hash<auto> request_xml, *list<hash<PropPatchActionInfo>> actions);  *hash<auto> fixDavPrefixes(string ns, hash<auto> h, *string pfx);
+     __7_ hash<auto> fixDavPrefixes(string ns, hash<auto> h, __7_ string pfx);
 public:
 
 
