@@ -32,31 +32,31 @@ public:
 
 
     //! Creates the object with the given argument and an in-memory property handler
-/** @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
+    /** @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
     constructor(string virtual_relative_path_base) ;
 
 
     //! Creates the object with the given arguments
-/** @param property_handler to handle properties
+    /** @param property_handler to handle properties
         @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
-    constructor(AbstractWebDavPropertyHandler property_handler, string virtual_relative_path_base = "/")
- ;
+    constructor(AbstractWebDavPropertyHandler property_handler, string virtual_relative_path_base = '/') ;
 
 
     //! Creates the object with the given arguments
-/** @param logger the logger
+    /** @param logger the logger
         @param property_handler to handle properties
         @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
-constructor(Logger logger, AbstractWebDavPropertyHandler property_handler = new InMemoryWebDavPropertyHandler(), string virtual_relative_path_base = '/') ;
+    constructor(Logger logger, AbstractWebDavPropertyHandler property_handler = new InMemoryWebDavPropertyHandler(), string virtual_relative_path_base = "/")
+ ;
 
 
-/**
+    /**
         GET
 
         Get a resource.
@@ -68,7 +68,7 @@ protected:
 public:
 
 
-/**
+    /**
         HEAD
 
         Same like GET but without sending a body.
@@ -80,7 +80,7 @@ protected:
 public:
 
 
-/**
+    /**
         POST
 
         Create new resource.
@@ -92,7 +92,7 @@ protected:
 public:
 
 
-/**
+    /**
         PUT
 
         Modify resource.
@@ -104,7 +104,7 @@ protected:
 public:
 
 
-/**
+    /**
         DELETE
 
         Delete a resource.
@@ -116,7 +116,7 @@ protected:
 public:
 
 
-/**
+    /**
         COPY
 
         Copy a resource from one URI to another.
@@ -128,7 +128,7 @@ protected:
 public:
 
 
-/**
+    /**
         MOVE
 
         Move a resource from one URI to another.
@@ -140,7 +140,7 @@ protected:
 public:
 
 
-/**
+    /**
         LOCK
 
         Put a lock on a resource. WebDavHandler supports both shared and exclusive locks.
@@ -152,7 +152,7 @@ protected:
 public:
 
 
-/**
+    /**
         UNLOCK
 
         Remove a lock from a resource.
@@ -164,7 +164,7 @@ protected:
 public:
 
 
-/**
+    /**
         MKCOL
 
         Create collections (aka a directory).
@@ -176,7 +176,7 @@ protected:
 public:
 
 
-/**
+    /**
         PROPFIND
 
         Retrieve properties, stored as XML, from a web resource. It is also
@@ -191,7 +191,7 @@ public:
 
 
     //! Internal method for handling PROPPATCH requests
-/** @param href the href for the response
+    /** @param href the href for the response
         @param cx the HTTP call context
         @param hdr as hash HTTP headers
         @param request_xml the parsed XML in the request
@@ -205,7 +205,7 @@ public:
         response
     */
 protected:
- __7_ hash<string, hash<string, hash<string, bool>>> handleProppatchImpl(reference<string> href, hash<auto> cx, hash<auto> hdr, *hash<auto> request_xml, *list<hash<PropPatchActionInfo>> actions);
+     __7_ hash<string, hash<string, hash<string, bool>>> handleProppatchImpl(reference<string> href, hash<auto> cx, hash<auto> hdr, *hash<auto> request_xml, *list<hash<PropPatchActionInfo>> actions);
 public:
 
 };
