@@ -42,41 +42,41 @@ protected:
 public:
 
     //! Creates the object with an empty logger and an in-memory property handler
-/** @param path the path on the local filesystem for WebDAV file handline
+    /** @param path the path on the local filesystem for WebDAV file handline
         @param auth the authentication object to use to authenticate connections
     */
     constructor(string path, __7_ HttpServer::AbstractAuthenticator auth) ;
 
 
     //! Creates the object with the given argument and an in-memory property handler
-/** @param path the path on the local filesystem for WebDAV file handline
+    /** @param path the path on the local filesystem for WebDAV file handline
         @param auth the authentication object to use to authenticate connections
         @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
-    constructor(string path, __7_ HttpServer::AbstractAuthenticator auth, string virtual_relative_path_base)
- ;
+    constructor(string path, __7_ HttpServer::AbstractAuthenticator auth, string virtual_relative_path_base) ;
 
 
     //! Creates the object with the given arguments
-/** @param path the path on the local filesystem for WebDAV file handline
+    /** @param path the path on the local filesystem for WebDAV file handline
         @param auth the authentication object to use to authenticate connections
         @param property_handler to handle properties
         @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
-constructor(string path, __7_ HttpServer::AbstractAuthenticator auth, AbstractWebDavPropertyHandler property_handler, string virtual_relative_path_base = '/') ;
+    constructor(string path, __7_ HttpServer::AbstractAuthenticator auth, AbstractWebDavPropertyHandler property_handler, string virtual_relative_path_base = "/")
+ ;
 
 
     //! Creates the object with the given arguments
-/** @param path the path on the local filesystem for WebDAV file handline
+    /** @param path the path on the local filesystem for WebDAV file handline
         @param auth the authentication object to use to authenticate connections
         @param logger the logger
         @param property_handler to handle properties
         @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
-constructor(string path, __7_ HttpServer::AbstractAuthenticator auth, Logger logger, AbstractWebDavPropertyHandler property_handler = new InMemoryWebDavPropertyHandler(), string virtual_relative_path_base = '/') ;
+    constructor(string path, __7_ HttpServer::AbstractAuthenticator auth, Logger logger, AbstractWebDavPropertyHandler property_handler = new InMemoryWebDavPropertyHandler(), string virtual_relative_path_base = '/') ;
 
 
     //! Common constructor initialization
@@ -86,7 +86,7 @@ public:
 
 
     //! Converts a request path to a normalized real path on the filesystem in the root WebDavHandler directory
-/** @throw WEBDAVHANDLER-FORBIDDEN if the path is not valid
+    /** @throw WEBDAVHANDLER-FORBIDDEN if the path is not valid
     */
 protected:
      string getRealPath(string raw_path);
@@ -107,7 +107,7 @@ public:
 
     //! Returns responses for each relevant resource
 private:
- list<hash<auto>> preparePropFindResponse(hash<auto> cx, string depth = 'infinity', hash<StatInfo> h, bool all_props, *hash<string, hash<string, bool>> additional_props);
+     list<hash<auto>> preparePropFindResponse(hash<auto> cx, string depth = 'infinity', hash<StatInfo> h, bool all_props, *hash<string, hash<string, bool>> additional_props);
 public:
 
 
@@ -117,7 +117,7 @@ public:
 
 
 private:
- hash<HttpResponseInfo> internalGet(Socket s, hash<auto> cx, hash<auto> hdr, __7_ data body, bool get = True);
+     hash<HttpResponseInfo> internalGet(Socket s, hash<auto> cx, hash<auto> hdr, __7_ data body, bool get = True);
 public:
 
 
@@ -127,7 +127,7 @@ public:
 
 
     //! Handles HTTP GET requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -167,7 +167,7 @@ public:
 
 
     //! Handles HTTP HEAD requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -209,7 +209,7 @@ public:
 
 
     //! Handles HTTP POST requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -251,7 +251,7 @@ public:
 
 
     //! Handles HTTP PUT requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -291,7 +291,7 @@ public:
 
 
     //! Handles HTTP DELETE requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -331,7 +331,7 @@ public:
 
 
     //! Handles WebDavHandler COPY requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -371,7 +371,7 @@ public:
 
 
     //! Handles WebDavHandler MOVE requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -411,7 +411,7 @@ public:
 
 
     //! Handles WebDavHandler LOCK requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -456,7 +456,7 @@ public:
 
 
     //! Handles WebDavHandler UNLOCK requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -496,7 +496,7 @@ public:
 
 
     //! Handles WebDavHandler MKCOL requests for WebDavHandler resources
-/**  @param cx call context hash; this hash will have the following keys:
+    /**  @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
             any of \c "*", \c "utf8", or \c "utf-8" are present, then this will be set to \c "utf8", otherwise it will
@@ -536,7 +536,7 @@ public:
 
 
     //! Handles WebDavHandler PROPFIND requests for WebDavHandler resources; reetrieves properties from WebDavHandler resources
-/**
+    /**
         @param cx call context hash; this hash will have the following keys:
         - \c header-info: a hash of information about the request header with the following keys:
           - \c accept-charset: this key will be set to an appropriate value from any \c "Accept-Charset" header; if
@@ -577,7 +577,7 @@ public:
 
 
     //! Internal method for handling PROPPATCH requests
-/** Create, change and delete one or more properties on a resource in a single atomic action
+    /** Create, change and delete one or more properties on a resource in a single atomic action
 
         @param cx the HTTP call context
         @param hdr as hash HTTP headers
@@ -589,7 +589,7 @@ public:
         @throw WEBDAVHANDLER-ERROR an error occured
     */
 protected:
- __7_ hash<string, hash<string, hash<string, bool>>> handleProppatchImpl(reference<string> href, hash<auto> cx, hash<auto> hdr, *hash<auto> request_xml, *list<hash<PropPatchActionInfo>> actions);
+     __7_ hash<string, hash<string, hash<string, bool>>> handleProppatchImpl(reference<string> href, hash<auto> cx, hash<auto> hdr, *hash<auto> request_xml, *list<hash<PropPatchActionInfo>> actions);
 public:
 
 
