@@ -1,7 +1,7 @@
 // -*- mode: c++; indent-tabs-mode: nil -*-
 // @file SalesforceSoapClient.qm Salesforce SOAP Client Definition Module
 
-/*  SalesforceSoapClient.qm Copyright (C) 2015 - 2022 Qore Technologies, s.r.o.
+/*  SalesforceSoapClient.qm Copyright (C) 2015 - 2023 Qore Technologies, s.r.o.
 
     Permission is hereby granted, free of charge, to any person obtaining a
     copy of this software and associated documentation files (the "Software"),
@@ -24,7 +24,7 @@
 
 
 
-}
+
 
 /** @mainpage SalesforceSoapClient Module
 
@@ -126,7 +126,7 @@ protected:
         string soapaction = "default";
 
         // perform a logout when destroying the object
-/** logouts should be performed manually to ensure that the user's session remains valid
+        /** logouts should be performed manually to ensure that the user's session remains valid
         */
         bool force_logout = False;
 
@@ -144,7 +144,7 @@ public:
 
 
     //! creates the object with the given options
-/** @param opts options for the SOAP connection; see @ref SoapClient::SoapClient::constructor() "SoapClient::constructor()" for option info for the embedded SoapClient, plus the following options:
+    /** @param opts options for the SOAP connection; see @ref SoapClient::SoapClient::constructor() "SoapClient::constructor()" for option info for the embedded SoapClient, plus the following options:
         - \c username: (required) Salesforce.com username
         - \c password: (required) Salesforce.com password
         - \c token: (required) Salesforce.com user API token
@@ -154,7 +154,7 @@ public:
 
 
     //! destroys the object
-/** @note if the \c force_logout option was given in the constructor(), then a logout from the Salesforce.com session is also performed
+    /** @note if the \c force_logout option was given in the constructor(), then a logout from the Salesforce.com session is also performed
     */
     destructor();
 
@@ -178,7 +178,7 @@ public:
 
 
     //! makes a server call with the given operation, arguments, options, and optional info hash reference and returns the result
-/** @param operation the SOAP operation to use to serialize the request; if the operation is not known to the underlying @ref WSDL::WebService "WebService" class, an exception will be thrown
+    /** @param operation the SOAP operation to use to serialize the request; if the operation is not known to the underlying @ref WSDL::WebService "WebService" class, an exception will be thrown
         @param args the arguments to the SOAP operation
         @param opts an optional hash of options for the call as follows:
         - \c soap_header: a hash giving SOAP header information, if required by the message
@@ -210,7 +210,7 @@ public:
 
 
     //! makes the internal call and returns the deserialized response
-/** @param operation the SOAP operation to use to serialize the request; if the operation is not known to the underlying @ref WSDL::WebService "WebService" class, an exception will be thrown
+    /** @param operation the SOAP operation to use to serialize the request; if the operation is not known to the underlying @ref WSDL::WebService "WebService" class, an exception will be thrown
         @param args the arguments to the SOAP operation
         @param opts an optional hash of options for the call as follows:
         - \c soap_header: a hash giving SOAP header information, if required by the message
@@ -244,7 +244,7 @@ public:
 
 
     //! makes a server call with the given operation and arguments and returns the deserialized result
-/** @param operation the operation name for the SOAP call
+    /** @param operation the operation name for the SOAP call
         @param args the operation parameter(s)
         @param header optional soap headers (if required by the operation)
 
@@ -254,7 +254,7 @@ public:
 
 
     //! makes a server call with the given operation and arguments and returns the deserialized result
-/** @param operation the operation name for the SOAP call
+    /** @param operation the operation name for the SOAP call
         @param args the arguments to the SOAP operation
         @param info an optional reference to return a hash of technical information about the SOAP call (raw message info and headers); the following keys are present in this hash:
         - \c "headers": a hash of HTTP request headers
@@ -274,7 +274,7 @@ public:
 
 
     //! makes a server call with the given operation and arguments and returns the deserialized result with an output argument giving technical information about the call
-/** @param info an optional reference to return a hash of technical information about the SOAP call (raw message info and headers); the following keys are present in this hash:
+    /** @param info an optional reference to return a hash of technical information about the SOAP call (raw message info and headers); the following keys are present in this hash:
         - \c "headers": a hash of HTTP request headers
         - \c "request-uri": the request URI string (ex: \c "POST /services/Soap/c/29.0 HTTP/1.1")
         - \c "response-uri": the response URI string (ex: \c "HTTP/1.1 200 OK")
@@ -301,7 +301,7 @@ public:
 
 
     //! uses call() to transparently serialize the argument and make a call to the given operation and return the deserialized results
-/** @param op the operation name, which is the method name passed to methodGate()
+    /** @param op the operation name, which is the method name passed to methodGate()
         @param arg a list or arguments or a single argument (or NOTHING) for the operation
 
         @return the deserialized result of the SOAP call to the SOAP server
@@ -355,7 +355,7 @@ protected:
 public:
 
     //! creates the SalesforceSoapConnection object
-/** @param name the name of the connection
+    /** @param name the name of the connection
         @param description connection description
         @param url connection URL (potentially with password info)
         @param attributes various attributes. See below
@@ -369,20 +369,56 @@ public:
  ;
 
 
+    //! Creates the SalesforceSoapConnection object
+    /** @param config with the following keys:
+        - name (required string): the connection name
+        - display_name (optional string): the display name
+        - short_desc (optional string): a short description in plain text
+        - desc (optional string): a long description with markdown formatting
+        - url (required string): the connection URL
+        - opts (optional hash): connection options
+        - logger (optional LoggerInterface object): logger for the connection
+        @param attr optional connection attributes
+        - monitor (optional bool): should the connection be monitored? Default: True
+        - enabled (optional bool): is the connection enabled? Default: True
+        - locked (optional bool): is the connection locked? Default: False
+        - debug_data (optional bool): debug data? Default: False
+        - tags (optional hash): tags for the connection; no default value
+
+        @throw CONNECTION-OPTION-ERROR missing or invalid connection option or attribute
+    */
+    constructor(hash<auto> config, __7_ hash<auto> attr) ;
+
+
+    //! Ensures that required options are set
+protected:
+     checkOpts();
+public:
+
+
     //! returns \c "sfsoap"
     string getType();
 
 
     //! returns runtime options
-/** @return a hash with the following keys reflecting support for the corresponding runtime options in getImpl() for connection logging:
+    /** @return a hash with the following keys reflecting support for the corresponding runtime options in getImpl() for connection logging:
         - \c "log": a closure accepting a single string for logging
         - \c "dbglog": a closure taking a single string for detailed technical connection logging
     */
     __7_ hash<auto> getRuntimeOptions();
 
 
+    //! returns @ref False
+    /** This connection type has not yet been updated to support the %Qore @ref Qore::Socket "Socket-based" polling
+        API
+
+        @return @ref False
+    */
+    bool supportsPollingApi();
+
+
     //! returns a @ref SalesforceSoapClient object
-/** @param connect if @ref Qore::True "True", then @ref SalesforceSoapClient::login() is called
+    /** @param connect if @ref Qore::True "True", then @ref SalesforceSoapClient::login() is called
         @param rtopts an optional hash providing two runtime options for connection logging:
         - \c "log": a closure accepting a single string for logging
         - \c "dbglog": a closure taking a single string for detailed technical connection logging
@@ -395,7 +431,7 @@ public:
 
 
     //! returns a WSDL::WebService object for the given URL using a cache for local files
-/** @param url the URL of the WSDL
+    /** @param url the URL of the WSDL
 
         @return a WSDL::WebService object corresponding to the WSDL URL
         */
