@@ -1,7 +1,7 @@
 // -*- mode: c++; indent-tabs-mode: nil -*-
 //! @file SoapClient.qm SOAP Client module implementation based on the WSDL classes
 
-/*  SoapClient.qm Copyright (C) 2012 - 2022 Qore Technologies, s.r.o.
+/*  SoapClient.qm Copyright (C) 2012 - 2023 Qore Technologies, s.r.o.
 
     Permission is hereby granted, free of charge, to any person obtaining a
     copy of this software and associated documentation files (the "Software"),
@@ -33,7 +33,6 @@
 
 // enable all warnings
 
-}
 
 /** @mainpage SoapClient Module
 
@@ -91,6 +90,14 @@ auto result = sc.call("SubmitDocument", msg);
 
     @section soapclientrelnotes SoapClient Release Notes
 
+    @subsection soapclient_1_0_1 SoapClient v1.0.1
+    - allow connection options designating files to be selected as files
+      (<a href="https://github.com/qorelanguage/qore/issues/4725">issue 4725</a>)
+
+    @subsection soapclient_1_0 SoapClient v1.0
+    - added information about data provider capabilities to connection info
+      (<a href="https://github.com/qorelanguage/qore/issues/4576">issue 4576</a>)
+
     @subsection soapclient_0_5 SoapClient v0.5
     - implemented support for a data provider scheme cache and rich option information for connections
       (<a href="https://github.com/qorelanguage/qore/issues/4025">issue 4025</a>)
@@ -141,12 +148,8 @@ auto result = sc.call("SubmitDocument", msg);
 
 //! main SoapClient namespace
 namespace SoapClient {
-//! SOAP client class implementation, publically inherits qore's HTTPClient class
-class SoapClient : public HTTPClient {
-
-public:
-    //! version of the implementation of this class
-    const Version = "0.2.5";
+//! SOAP client class implementation, publically inherits qore's HTTPClient class public class SoapClient inherits HTTPClient {    //! version of the implementation of this class
+    const Version = "1.0.1";
 
     //! default HTTP headers
     const Headers = {"User-Agent": ("Qore-Soap-Client/" + SoapClient::Version)};
@@ -155,7 +158,7 @@ public:
     const HTTPOptions = keys HttpConnection::ConnectionScheme.options;
 
     //! @cond nodoc
-protected:
+    private {
         // web service definition
         WSDL::WebService wsdl;
         // service name
@@ -169,17 +172,17 @@ protected:
 
         // send content encoding hash
         __7_ hash<auto> seh;
-
-public:
+    }
     //! @endcond
 
+    public {
         //! target URL
         string url;
         //! HTTP headers to use
         hash headers = Headers;
 
         //! Send content encoding options
-/** Send content encoding options are as follows:
+        /** Send content encoding options are as follows:
             - \c "bzip": use bzip2 compression
             - \c "gzip": use gzip compression
             - \c "deflate": use deflate compression
@@ -190,9 +193,10 @@ public:
 
         //! default threadhold for data compressions; transfers smaller than this size will not be compressed
         const CompressionThreshold = 1024;
+    }
 
     //! creates the object based on a %WSDL which is parsed to a @ref WSDL::WebService "WebService" object which provides the basis for all communication with this object
-/** one of either the \c wsdl or \c wsdl_file keys is required in the hash given to the constructor or an exception will be thrown
+    /** one of either the \c wsdl or \c wsdl_file keys is required in the hash given to the constructor or an exception will be thrown
         @param h valid option keys:
         - \c wsdl: the URL of the web service or a @ref WSDL::WebService "WebService" object itself
         - \c wsdl_file: a path to use to load the %WSDL and create the @ref WSDL::WebService "WebService" object
@@ -209,7 +213,7 @@ public:
 
 
     //! returns a hash representing the serialized SOAP request for a given @ref WSDL::WSOperation "WSOperation"
-/** @param operation the SOAP operation to use to serialize the request; if the operation is not known to the underlying @ref WSDL::WebService "WebService" class and port/binding, an exception will be thrown
+    /** @param operation the SOAP operation to use to serialize the request; if the operation is not known to the underlying @ref WSDL::WebService "WebService" class and port/binding, an exception will be thrown
         @param args the arguments to the SOAP operation
         @param soap_header data structure for the SOAP header, if required by the message
         @param op a reference to return the @ref WSDL::WSOperation "WSOperation" object found
@@ -232,7 +236,7 @@ public:
 
 
     //! makes a server call with the given operation, arguments, options, and optional info hash reference and returns the result
-/** @param operation the SOAP operation to use to serialize the request; if the operation is not known to the underlying @ref WSDL::WebService "WebService" class, an exception will be thrown
+    /** @param operation the SOAP operation to use to serialize the request; if the operation is not known to the underlying @ref WSDL::WebService "WebService" class, an exception will be thrown
         @param args the arguments to the SOAP operation
         @param opts an optional hash of options for the call as follows:
         - \c soap_header: a hash giving SOAP header information, if required by the message
@@ -268,7 +272,7 @@ public:
 
 
     //! makes a server call with the given operation and arguments and returns the deserialized result
-/** @param operation the operation name for the SOAP call
+    /** @param operation the operation name for the SOAP call
         @param args the arguments to the SOAP operation
         @param soap_header optional soap headers (if required by the operation)
         @param http_header a hash giving HTTP header information to include in the message (does not override automatically-generated SOAP message headers)
@@ -290,7 +294,7 @@ public:
 
 
     //! makes a server call with the given operation and arguments and returns the deserialized result
-/** @param operation the operation name for the SOAP call
+    /** @param operation the operation name for the SOAP call
         @param args the arguments to the SOAP operation
         @param info an optional reference to return a hash of technical information about the SOAP call (raw message info and headers); the following keys are present in this hash:
         - \c "headers": a hash of HTTP request headers
@@ -321,7 +325,7 @@ public:
 
 
     //! makes a server call with the given operation and arguments and returns the deserialized result with an output argument giving technical information about the call
-/** @param info an optional reference to return a hash of technical information about the SOAP call (raw message info and headers); the following keys are present in this hash:
+    /** @param info an optional reference to return a hash of technical information about the SOAP call (raw message info and headers); the following keys are present in this hash:
         - \c "headers": a hash of HTTP request headers
         - \c "request-uri": the request URI string (ex: \c "POST /services/Soap/c/29.0 HTTP/1.1")
         - \c "response-uri": the response URI string (ex: \c "HTTP/1.1 200 OK")
@@ -359,7 +363,7 @@ public:
 
 
     //! uses SoapClient::call() to transparently serialize the argument and make a call to the given operation and return the deserialized results
-/** @param op the operation name, which is the method name passed to methodGate()
+    /** @param op the operation name, which is the method name passed to methodGate()
         @param ... zero or more arguments for the operation
 
         @return the deserialized result of the SOAP call to the SOAP server
@@ -383,7 +387,7 @@ public:
 
 
     //! returns a hash of information about the current WSDL
-/** @return a hash with the following keys:
+    /** @return a hash with the following keys:
         - \c "service": the name of the SOAP service used
         - \c "pore": the name of the SOAP port used
         - \c "binding": the name of the binding used
@@ -393,7 +397,7 @@ public:
 
 
     //! change the data content encoding (compression) option for the object; see @ref EncodingSupport for valid options
-/** @par Example:
+    /** @par Example:
         @code{.py}
 sc.setSendEncoding("gzip");
         @endcode
@@ -412,7 +416,7 @@ sc.setSendEncoding("gzip");
 
 
     //! sets the request and desired response encoding for the object; see @ref EncodingSupport for valid options
-/** @par Example:
+    /** @par Example:
         @code{.py}
 soap.setContentEncoding("gzip");
         @endcode
@@ -431,7 +435,7 @@ soap.setContentEncoding("gzip");
 
 
     //! adds default headers to each request; these headers will be sent in all requests but can be overridden in requests as well
-/** @par Example:
+    /** @par Example:
         @code{.py}
 # disable gzip and bzip encoding in responses
 soap.addDefaultHeaders(("Accept-Encoding": "compress"));
@@ -449,7 +453,7 @@ soap.addDefaultHeaders(("Accept-Encoding": "compress"));
 
 
     //! returns the hash of default headers to sent in all requests
-/** @par Example:
+    /** @par Example:
         @code{.py}
 hash<auto> h = soap.getDefaultHeaders();
         @endcode
@@ -466,7 +470,7 @@ hash<auto> h = soap.getDefaultHeaders();
 
 
     //! returns the current data content encoding (compression) object or @ref nothing if no encoding option is set; see @ref EncodingSupport for valid options
-/** @par Example:
+    /** @par Example:
         @code{.py}
 *string ce = soap.getSendEncoding();
         @endcode
@@ -489,7 +493,7 @@ hash<auto> h = soap.getDefaultHeaders();
     //! sends a log message to the debug log closure or call reference, if any
     dbglog(string msg);
 
-/** Method is to be overriden to implement custom logging HTTP message sent and received from this object.
+    /** Method is to be overriden to implement custom logging HTTP message sent and received from this object.
         @par msg information about message to be logged. There are keys 'reason' with value 'request', 'response' or 'error',
                 'header' (HTTP headers, as received from the remote) and 'body' containing XML data in readable form, i.e. uncompressed, and, in case of
                 a multipart message, only the related part is passed. Method is executed before message is sent or after
@@ -508,7 +512,7 @@ protected:
      nothing msglog(hash<auto> msg);
 public:
 
-};
+}
 
 //! class for SOAP connections; returns an object of class @ref SoapClient for connecting to SOAP servers
 /** supports all @ref ConnectionProvider::HttpConnection "HttpConnection" options plus the following static
@@ -537,7 +541,7 @@ public:
 
 
     //! creates the SoapConnection object
-/** @param name the name of the connection
+    /** @param name the name of the connection
         @param description connection description
         @param url connection URL (potentially with password info)
         @param attributes various attributes. See below
@@ -549,12 +553,33 @@ public:
  ;
 
 
+    //! Creates the SoapConnection object
+    /** @param config with the following keys:
+        - name (required string): the connection name
+        - display_name (optional string): the display name
+        - short_desc (optional string): a short description in plain text
+        - desc (optional string): a long description with markdown formatting
+        - url (required string): the connection URL
+        - opts (optional hash): connection options
+        - logger (optional LoggerInterface object): logger for the connection
+        @param attr optional connection attributes
+        - monitor (optional bool): should the connection be monitored? Default: True
+        - enabled (optional bool): is the connection enabled? Default: True
+        - locked (optional bool): is the connection locked? Default: False
+        - debug_data (optional bool): debug data? Default: False
+        - tags (optional hash): tags for the connection; no default value
+
+        @throw CONNECTION-OPTION-ERROR missing or invalid connection option or attribute
+    */
+    constructor(hash<auto> config, __7_ hash<auto> attr) ;
+
+
     //! returns \c "soap"
     string getType();
 
 
     //! returns runtime options
-/** @return a hash with the following keys reflecting support for the corresponding runtime options in getImpl() for connection logging:
+    /** @return a hash with the following keys reflecting support for the corresponding runtime options in getImpl() for connection logging:
         - \c "log": a closure accepting a single string for logging
         - \c "dbglog": a closure taking a single string for detailed technical connection logging
     */
@@ -562,7 +587,7 @@ public:
 
 
     //! returns a data provider object for this connection
-/** @return a data provider object for this connection
+    /** @return a data provider object for this connection
 
         @see hasDataProvider()
     */
@@ -570,15 +595,36 @@ public:
 
 
     //! returns @ref True as this connection returns a data provider with the @ref getDataProvider() method
-/** @return @ref True as this connection returns a data provider with the @ref getDataProvider() method
+    /** @return @ref True as this connection returns a data provider with the @ref getDataProvider() method
 
         @see @ref getDataProvider()
     */
     bool hasDataProvider();
 
 
+    //! returns @ref False
+    /** This connection type has not yet been updated to support the %Qore @ref Qore::Socket "Socket-based" polling
+        API
+
+        @return @ref False
+    */
+    bool supportsPollingApi();
+
+
+    //! Common constructor initialization
+protected:
+     soapSetup();
+public:
+
+
+    //! Set child capabilities
+protected:
+     setChildCapabilities();
+public:
+
+
     //! returns a @ref SoapClient object
-/** @param connect if @ref Qore::True "True", then @ref Qore::HTTPClient::connect() "SoapClient::connect()" is called
+    /** @param connect if @ref Qore::True "True", then @ref Qore::HTTPClient::connect() "SoapClient::connect()" is called
         @param rtopts supports the following runtime options in getImpl() for connection logging:
         - \c "log": a closure accepting a single string for logging
         - \c "dbglog": a closure taking a single string for detailed technical connection logging
@@ -596,4 +642,4 @@ protected:
 public:
 
 };
-};
+}
