@@ -24,6 +24,9 @@
 
 //! contains all public definitions in the SoapDataProvider module
 namespace SoapDataProvider {
+//! The application name for SOAP servers
+const AppName = "SOAP";
+
 //! The Soap data provider class
 class SoapDataProvider : public AbstractDataProvider {
 
@@ -67,7 +70,7 @@ public:
 
 
     //! Returns a list of child data provider names, if any
-/** @return a list of child data provider names, if any
+    /** @return a list of child data provider names, if any
     */
 protected:
      __7_ list<string> getChildProviderNamesImpl();
@@ -75,7 +78,7 @@ public:
 
 
     //! Returns the given child provider or @ref nothing if the given child is unknown
-/** @return the given child provider or @ref nothing if the given child is unknown
+    /** @return the given child provider or @ref nothing if the given child is unknown
 
         @see getChildProviderEx()
     */
