@@ -29,7 +29,6 @@
 // enable all warnings
 
 
-}
 
 /** @mainpage SoapDataProvider Module
 
@@ -64,6 +63,10 @@
 
     @section soapdataprovider_relnotes Release Notes
 
+    @subsection soapdataprovider_v2_0 SoapDataProvider v2.0
+    - added support for the data provider action catalog API
+      (<a href="https://github.com/qorelanguage/qore/issues/4808">issue 4808</a>)
+
     @subsection soapdataprovider_v1_1 SoapDataProvider v1.1
     - fixed a bug where data providers could return local names as paths with \c "/" characters in them, breaking
       some clients traversing the data provider hierarchy
@@ -76,3 +79,10 @@
 //! contains all public definitions in the SoapDataProvider module
 namespace SoapDataProvider {
 };
+
+namespace Priv {
+    const SoapLogoLight = ...;
+
+    const SoapLogoDark = ...;
+
+};
\ No newline at end of file
