@@ -35,8 +35,7 @@ public:
         __7_ hash<string, AbstractDataField> record_type;
 
     //! Creates the object from the arguments
-    constructor(WebService webservice, __7_ SoapClient soapclient, WSOperation op)
- ;
+    constructor(WebService webservice, __7_ SoapClient soapclient, WSOperation op) ;
 
 
     //! Returns the data provider name
@@ -48,7 +47,7 @@ public:
 
 
     //! Returns the description of the record type, if any
-/** Returns the record type description for any successful response
+    /** Returns the record type description for any successful response
     */
 protected:
      __7_ hash<string, AbstractDataField> getRecordTypeImpl(__7_ hash<auto> search_options);
@@ -62,7 +61,7 @@ public:
 
 
     //! Returns the description of a response message, if this object represents a response message
-/** If the object is a request message, then any successful response message should be returned here as well
+    /** If the object is a request message, then any successful response message should be returned here as well
 
         @return the response type for this response message
 
@@ -80,7 +79,7 @@ public:
 
 
     //! Makes a request and returned the response
-/** @param req the request to serialize and make according to the request type
+    /** @param req the request to serialize and make according to the request type
         @param request_options the request options; will be processed by validateRequestOptions()
 
         @return the response to the request
@@ -91,7 +90,7 @@ public:
 
 
     //! Returns an iterator for zero or more records matching the search options
-/** @param where_cond the search criteria
+    /** @param where_cond the search criteria
         @param search_options the search options after processing by validateSearchOptions()
 
         This will execute the request and perform a default search on any record(s) returned
