@@ -261,51 +261,51 @@ public:
       static string getSoapMimeType12(bool soap12);
 
     //! retrieves a local file and returns the file's contents as a string
-/** called by WSDLLib::getFileFromURL() in case the scheme is "file"
+    /** called by WSDLLib::getFileFromURL() in case the scheme is "file"
     */
       static data getFile(string fn, bool as_string = True);
 
     //! retrieves a file from a URL with HTTP and returns the file's contents as a string
-/** called by WSDLLib::getFileFromURL() in case the scheme is "http"
+    /** called by WSDLLib::getFileFromURL() in case the scheme is "http"
     */
       static string getHTTP(string url, __7_ string path, __7_ HTTPClient hc, __7_ hash<auto> headers, bool as_string = True);
 
     //! retrieves a file from a URL with the FTP protocol and returns the file's contents as binary or string data
-/** called by WSDLLib::getFileFromURL() in case the scheme is "ftp"
+    /** called by WSDLLib::getFileFromURL() in case the scheme is "ftp"
     */
       static data getFTP(string url, string path, bool as_string = True);
 
     //! retrieves a file from a URL
-/** in case the URL is actually a file path, environment variable substitution
+    /** in case the URL is actually a file path, environment variable substitution
         is performed on the path string
 
         @note uses the \c FileLocationHandler module to retrieve file data for all schemes except \c "file://" and
         \c "http(s)://", which uses @ref WSDL::WSDLLib::getFileFromUrl() "WSDLLib::getFileFromUrl()" and
         @ref WSDL::WSDLLib::getHTTP() "WSDLLib::getHTTP()" respectively for backwards compatibility
      */
-  static data getFileFromURL(string url, string def_protocol = 'file', __7_ HTTPClient http_client, *hash<auto> http_headers, bool as_string = True, *string def_path, *reference new_def_path);
+      static data getFileFromURL(string url, string def_protocol = 'file', __7_ HTTPClient http_client, *hash<auto> http_headers, bool as_string = True, *string def_path, *reference new_def_path);
 
     //! retrieves a file from an already-parsed URL
-/** in case the URL is actually a file path, environment variable substitution
+    /** in case the URL is actually a file path, environment variable substitution
         is performed on the path string
 
         @note uses the \c FileLocationHandler module to retrieve file data for all schemes except \c "file://" and
         \c "http(s)://", which uses @ref WSDL::WSDLLib::getFileFromUrl() "WSDLLib::getFileFromUrl()" and
         @ref WSDL::WSDLLib::getHTTP() "WSDLLib::getHTTP()" respectively for backwards compatibility
      */
-  static data getFileFromURL(string url, hash<auto> u, string def_protocol = 'file', __7_ HTTPClient http_client, *hash<auto> http_headers, bool as_string = False, *string def_path, *reference new_def_path);
+      static data getFileFromURL(string url, hash<auto> u, string def_protocol = 'file', __7_ HTTPClient http_client, *hash<auto> http_headers, bool as_string = False, *string def_path, *reference new_def_path);
 
     //! returns the argument
       static WebService getWSDL(WebService wsdl);
 
     //! returns a WSDL string from a file name, optional HTTPClient object and optional header hash
-/** in case the \a wsdl argument is actually a file path, environment variable substitution
+    /** in case the \a wsdl argument is actually a file path, environment variable substitution
         is performed on the path string
      */
       static string getWSDL(string wsdl, __7_ HTTPClient http_client, __7_ hash<auto> http_headers, __7_ reference new_def_path);
 
     //! returns a WebService object from a URL and other optional arguments
-/** @param the URL to use to retrieve the file, the \c "file://", \c "http://", \c "https://", and \c "ftp://" schemes are supported, if no scheme is present, then \c "file://" is assumed
+    /** @param the URL to use to retrieve the file, the \c "file://", \c "http://", \c "https://", and \c "ftp://" schemes are supported, if no scheme is present, then \c "file://" is assumed
         @param http_client an optional HTTPClient object to use to retrieve external schemas, if no HTTPClient object is passed and one is needed, an HTTPClient object will be created implicitly
         @param http_headers any HTTP headers to send with requests when retrieving external XSD schemas
     */
@@ -317,7 +317,7 @@ public:
     //! returns True is the message has a SOAP mime type
       static bool isSOAPMessage(hash<auto> msg);
 
-/**!
+    /**!
     takes a hash representation returned by parseMultiPartSOAPMessage and parses it to a Qore data structure, checks the content-type, and handles hrefs in the message.
     Operation is not yet known if SoapAction header is not presented
     */
@@ -522,7 +522,7 @@ public:
         __7_ string ref;
         bool usedocns;
 
-constructor(hash<auto> e, Namespaces nsc, __7_ XsdAbstractType n_type, XsdLateResolverHelper unresolved, bool n_usedocns) ;
+    constructor(hash<auto> e, Namespaces nsc, __7_ XsdAbstractType n_type, XsdLateResolverHelper unresolved, bool n_usedocns) ;
 
 
     AbstractDataProviderType getDataProviderType();
@@ -575,10 +575,10 @@ public:
     __7_ hash<string, AbstractDataField> getFields();
 
 
-    hash<string, bool> getAcceptTypeHash();
+    hash<string, bool> getAcceptTypeHash(__7_ bool simple);
 
 
-    hash<string, bool> getReturnTypeHash();
+    hash<string, bool> getReturnTypeHash(__7_ bool simple);
 
 
     auto acceptsValue(auto value);
@@ -597,8 +597,7 @@ public:
         AbstractDataProviderType dataType;
         bool usedocns;
 
-    constructor(hash<auto> st, Namespaces nsc, XsdLateResolverHelper unresolved, bool n_usedocns, __7_ string desc_name)
- ;
+    constructor(hash<auto> st, Namespaces nsc, XsdLateResolverHelper unresolved, bool n_usedocns, __7_ string desc_name) ;
 
 
     finalizeResolved();
@@ -671,8 +670,7 @@ protected:
 public:
 
     // ct can be NOTHING in case of an empty complex type
-    constructor(__7_ hash<auto> ct, Namespaces nsc, XsdLateResolverHelper unresolved, bool n_usedocns, __7_ string desc_name)
- ;
+    constructor(__7_ hash<auto> ct, Namespaces nsc, XsdLateResolverHelper unresolved, bool n_usedocns, __7_ string desc_name) ;
 
 
     __7_ list<auto> getAllowedValues();
@@ -708,13 +706,18 @@ public:
 
 
 protected:
- hash<string, XsdElement> parseElements(softlist<auto> el, XsdLateResolverHelper unresolved, Namespaces nsc, bool for_object = True);
+     hash<string, XsdElement> parseElements(softlist<auto> el, XsdLateResolverHelper unresolved, Namespaces nsc, bool for_object = True);
 public:
 
 
     AbstractDataProviderType getDataProviderType();
 
 
+protected:
+     AbstractDataProviderType getDataProviderTypeIntern();
+public:
+
+
 protected:
      __7_ hash<auto> serializeElement(Namespaces nsc, string key, XsdElement element, auto h, __7_ softbool omitType);
 public:
@@ -724,7 +727,7 @@ public:
 
 
 protected:
- hash<auto> serializeChoice(Namespaces nsc, hash<string, XsdElement> emap, hash<auto> h, *softbool omitType, bool all_members);
+     hash<auto> serializeChoice(Namespaces nsc, hash<string, XsdElement> emap, hash<auto> h, *softbool omitType, bool all_members);
 public:
 
 
@@ -732,7 +735,7 @@ public:
 
 
 protected:
- __7_ hash<auto> parseChoice(hash<auto> val, hash<string, XsdElement> emap, string en, hash<string, XsdAbstractType> tmap, *hash<auto> mrh, *bool required);
+     __7_ hash<auto> parseChoice(hash<auto> val, hash<string, XsdElement> emap, string en, hash<string, XsdAbstractType> tmap, *hash<auto> mrh, *bool required);
 public:
 
 };
@@ -769,7 +772,7 @@ protected:
 public:
 
     //! creates the WSOperation object from the arguments supplied
-/** @param p the raw hash from deserialized XML data for the operation
+    /** @param p the raw hash from deserialized XML data for the operation
         @param nsc the namespace container
         @param messages a hash of messages defined in the WSDL; keys are message names; values are WSMessage objects
      */
@@ -797,7 +800,7 @@ public:
 
 
     //! returns a hash representing the given binding
-/** @param bname the name of the binding, if not provided then uses the first assigned binding
+    /** @param bname the name of the binding, if not provided then uses the first assigned binding
 
         @return a binding param hash describing the binding with the following keys:
         - \c "httpMethod"
@@ -809,7 +812,7 @@ public:
 
 
     //! adds the given binding
-/** @param bname binding name, must be unique in operation
+    /** @param bname binding name, must be unique in operation
         @param opparams a hash with the following keys:
         - \c "httpMethod"
         - \c "soapTransport"
@@ -820,7 +823,7 @@ public:
 
 
     //! serializes a fault response to an XML string or HTTP payload for the operation.
-/** @param fault an optional fault message for the operation (@see getFaultMessages())
+    /** @param fault an optional fault message for the operation (@see getFaultMessages())
         @param h the fault data to serialize
         @param header optional soap header info to serialize if required (ex: authorization info). In the first step
         headers are matched to binding/input/header WSDL definition, remaining headers are passed as-is
@@ -840,11 +843,11 @@ public:
         - \c path: the path part of URL. Used when urlEncoded is defined
         - \c method: the HTTP request method
     */
-hash<auto> serializeFault(__7_ string fault, string faultmsg, auto h, __7_ hash<auto> header, __7_ string enc, *hash<auto> nsh, *int xml_opts, *string req_soapaction, *string bname);
+    hash<auto> serializeFault(__7_ string fault, string faultmsg, auto h, __7_ hash<auto> header, __7_ string enc, *hash<auto> nsh, *int xml_opts, *string req_soapaction, *string bname);
 
 
     //! serializes a request to an XML string or HTTP payload for the operation.
-/** @param h the request to serialize
+    /** @param h the request to serialize
         @param header optional soap header info to serialize if required (ex: authorization info). In the first step
         headers are matched to binding/input/header WSDL definition, remaining headers are passed as-is
         @param enc the optional encoding to use; if this argument is not present, then the default encoding will be
@@ -869,7 +872,7 @@ hash<auto> serializeFault(__7_ string fault, string faultmsg, auto h, __7_ hash<
 
 
     //! serializes a SOAP response to an XML string for the operation
-/** @param h the response to serialize
+    /** @param h the response to serialize
         @param header SOAP header hash. In the first step headers are matched to binding/input/header WSDL definition,
         remaining headers are passed as-is
         @param enc the optional encoding to use; if this argument is not present, then the default encoding will be
@@ -893,7 +896,7 @@ hash<auto> serializeFault(__7_ string fault, string faultmsg, auto h, __7_ hash<
 
 
     //! parses a hash representing a parsed XML request (parsed with @ref parse_xml() "parse_xml(XPF_PRESERVE_ORDER)") for the operation and returns the corresponding Qore data structure
-/** @param o the parsed SOAP or HTTP request with @ref WSDLLib::parseSOAPMessage() for the operation
+    /** @param o the parsed SOAP or HTTP request with @ref WSDLLib::parseSOAPMessage() for the operation
         @param bname SOAP binding name, leave empty to use the first assigned binding
         @return the Qore data structure corresponding to the request data. When SOAP header is deserialized according binding/input WSDL then all data are passed under subhash vales prefixed by message name
         In case of HTTP binding the content type is matched against WSDL binding when wildcards are supported and current content type value is applied to "^attributes^"."^content-type^".
@@ -902,7 +905,7 @@ hash<auto> serializeFault(__7_ string fault, string faultmsg, auto h, __7_ hash<
 
 
     //! parses a hash representing a parsed XML response (parsed with @ref parse_xml() "parse_xml(XPF_PRESERVE_ORDER)") for the operation and returns the corresponding Qore data structure
-/** @param o the parsed SOAP or HTTP request with @ref WSDLLib::parseSOAPMessage() for the operation
+    /** @param o the parsed SOAP or HTTP request with @ref WSDLLib::parseSOAPMessage() for the operation
         @param bname SOAP binding name, leave empty to use the first assigned binding
         @return the Qore data structure corresponding to the response data. When SOAP header is deserialized according binding/output WSDL then all data are passed under subhash vales prefixed by message name
         In case of HTTP binding the content type is matched against WSDL binding when wildcards are supported and current content type value is applied to "^attributes^"."^content-type^".
@@ -910,7 +913,7 @@ hash<auto> serializeFault(__7_ string fault, string faultmsg, auto h, __7_ hash<
     auto deserializeResponse(hash<auto> o, __7_ string bname);
 
 
-/** Operation is resolved from method and path so let's look if data are passed in URL.
+    /** Operation is resolved from method and path so let's look if data are passed in URL.
         When URL replacement is defined for operation then exception is raised.
         @return NOTHING if data are not encoded in URL for operation
     */
@@ -924,13 +927,13 @@ public:
 
 
     //! returns True if the operation is a SOAP 1.2 operation
-/** @return True if the operation is a SOAP 1.2 operation
+    /** @return True if the operation is a SOAP 1.2 operation
     */
     bool isSoap12();
 
 
     //! returns the target namespace for the operation
-/** @return the target namespace for the operation
+    /** @return the target namespace for the operation
     */
     string getTargetNS();
 
@@ -980,7 +983,7 @@ public:
     AbstractDataProviderType getDataProviderType();
 
 
-/**
+    /**
         Just serialize value and return namespace
         @param ons is reference to string
     */
@@ -988,7 +991,7 @@ public:
 
 
     //! serializes data into a hash with SOAP namespaces etc. with RPC-style messages
-/**
+    /**
         @param parts if present then serializes only particular element or part, if NOTHING then serializes all message elements
         @param msginfo a description of the message for the current binding, if available
         @param n_name name of output key
@@ -1000,7 +1003,7 @@ public:
 
 
     //! serializes data into a hash with SOAP namespaces etc. with document-style messages
-/**
+    /**
         @param parts if present then serializes only particular element or part, if NOTHING then serializes all message elements
         @param msginfo a description of the message for the current binding, if available
         @param mpm a multipart message object, for future use
@@ -1012,7 +1015,7 @@ public:
 
 
     //! deserialize RPC message
-/**
+    /**
     @param val, keys are element names or part names for simple types
     @param part if exists then deserialize only particular part
     @return serialized data, keys are wsdl element names (optionally part name is also possible) and part names for simple types
@@ -1024,14 +1027,14 @@ public:
 
 
     //! serialize all values as string or binary
-/**
+    /**
         @return hash of all parts in key-value pair
     */
     hash<auto> serializeAllPartData(__7_ hash<auto> val);
 
 
     //! serialized value of particular type value as string or binary
-/**
+    /**
         @param val value to be resolved
         @param key member name, it is requires reference to a simple type, not compaund element
 
@@ -1041,21 +1044,21 @@ public:
 
 
     //! deserialize value in string or binary form
-/**
+    /**
         @return hash<auto> in key-value pair
     */
     hash<auto> deserializeData(string part, hash<auto> val);
 
 
     //! deserialize all values in string or binary form
-/**
+    /**
         @return hash of all parts in key-value pair
     */
     hash<auto> deserializeAllPartData(hash<auto> val);
 
 
     //! find part in value, remove that value from the hash
-/**
+    /**
         @param ename element/type name
         @param v reference to hash, supposed structure is [msgname.](partname|elemname) = value to support more message data in one hash
         @param removeFound if True found values are removed from the hash
@@ -1077,7 +1080,7 @@ public:
 
 
     //! check if pname is defined as message part
-/** @return translated part name to element/type name
+    /** @return translated part name to element/type name
      */
     string checkPart(string pname);
 
@@ -1155,7 +1158,7 @@ public:
 
 
 private:
- hash<auto> serializeSoapMessage(WSOperation op, __7_ WSMessage msg, auto val, __7_ hash<auto> header, *hash<auto> nsh, bool request, bool soap12, reference mpm, *string faultmsg);
+     hash<auto> serializeSoapMessage(WSOperation op, __7_ WSMessage msg, auto val, __7_ hash<auto> header, *hash<auto> nsh, bool request, bool soap12, reference mpm, *string faultmsg);
 public:
 
 
@@ -1178,10 +1181,11 @@ public:
         string httpMethod;
         string location;
 
-constructor(string name, string ns, bool docstyle, string httpMethod, string location, __7_ string soapAction, *WSDL::BindingMessageDescription input, *WSDL::BindingMessageDescription output) ;
+    constructor(string name, string ns, bool docstyle, string httpMethod, string location, __7_ string soapAction, *WSDL::BindingMessageDescription input, *WSDL::BindingMessageDescription output)
+ ;
 
 
-hash<auto> serializeMessageImpl(WSOperation op, __7_ WSMessage msg, bool request, bool soap12, auto h, *hash<auto> header, string enc, *hash<auto> nsh, *int xml_opts, *string req_soapaction, *string faultmsg, *hash<auto> http_headers);
+    hash<auto> serializeMessageImpl(WSOperation op, __7_ WSMessage msg, bool request, bool soap12, auto h, *hash<auto> header, string enc, *hash<auto> nsh, *int xml_opts, *string req_soapaction, *string faultmsg, *hash<auto> http_headers);
 
 
     //! serializes path part of URL when urlEncoded WSDL is defined
@@ -1204,7 +1208,7 @@ class WSDL::BindingMessageBodyDescription : public Serializable {
 
 public:
         //! required attribute
-/** if @ref Qore::True "True", then use = \c "encoded" (each message part references an abstract type using the \c type attribute),
+        /** if @ref Qore::True "True", then use = \c "encoded" (each message part references an abstract type using the \c type attribute),
             otherwise use = \c "literal" (each part references a concrete schema definition using either the \c element or \c type attribute)
          */
         bool encoded;
@@ -1233,7 +1237,7 @@ public:
         string part;
 
         //! required attribute
-/** if @ref Qore::True "True", then use = \c "encoded" (each message part references an abstract type using the \c type attribute),
+        /** if @ref Qore::True "True", then use = \c "encoded" (each message part references an abstract type using the \c type attribute),
             otherwise use = \c "literal" (each part references a concrete schema definition using either the \c element or \c type attribute)
             */
         bool encoded;
@@ -1283,7 +1287,7 @@ class WSDL::MimeXmlMessageDescription : public Serializable {
 
 public:
         //! refers to a message part defining the concrete schema of the root XML element
-/** The part references a concrete schema using the element attribute for simple parts or type attribute for composite parts
+        /** The part references a concrete schema using the element attribute for simple parts or type attribute for composite parts
          */
         string part;
 
@@ -1299,12 +1303,12 @@ public:
         __7_ WSDL::BindingMessageBodyDescription body;
 
         //! a hash of URL replacement values keyed by part name, values are URI paths
-/** @note for HTTP bindings only
+        /** @note for HTTP bindings only
          */
         __7_ hash<auto> urlReplacement;
 
         //! indicates that all the message parts are encoded into the HTTP request URI using the standard URI-encoding rules
-/** ex: name1=value&name2=value...
+        /** ex: name1=value&name2=value...
 
             The names of the parameters correspond to the names of the message parts.
             Each value contributed by the part is encoded using a name=value pair.
@@ -1352,7 +1356,7 @@ private:
         string port;
 
         //! use RPC or document style
-/** according to https://www.w3.org/TR/wsdl#_soap:operation
+        /** according to https://www.w3.org/TR/wsdl#_soap:operation
             'If the soap:binding element does not specify a style, it is assumed to be "document".'
          */
         bool docstyle = True;
@@ -1633,7 +1637,7 @@ public struct WSDL::OperationInfo {
 //! main class representing a parsed WSDL file
 /** This is the main class for handling SOAP communication and is based on a WSDL file
 */
-class WSDL::WebService : public WSDL::XsdBase,public  Qore::Serializable {
+class WSDL::WebService : public WSDL::XsdBase, public Qore::Serializable {
 
 public:
         //! the WSDL string
@@ -1649,12 +1653,12 @@ public:
         bool has_try_import = False;
 
         //! the name of the WebService
-/** @since %WSDL 0.5
+        /** @since %WSDL 0.5
         */
         string name;
 
         //! the digest of the WSDL source
-/** @since %WSDL 0.5
+        /** @since %WSDL 0.5
         */
         string hash_str;
 
@@ -1683,7 +1687,7 @@ public:
         transient __7_ code try_import;
 
         //! default path for retrieving XSD references
-/** @note there is no need to serialize \c def_path as it will be set with the saved options
+        /** @note there is no need to serialize \c def_path as it will be set with the saved options
         */
         transient __7_ string def_path;
 
@@ -1700,7 +1704,7 @@ protected:
 public:
 
     //! creates the WebService object
-/** @param str the XML string representing the WSDL
+    /** @param str the XML string representing the WSDL
         @param opts an optional hash of options with the following possible keys:
         - \c "compat_allow_any_header": allow any SOAP header to be sent without checking the WSDL
         - \c "compat_empty_string_is_nothing": deserialize empty strings to @ref nothing instead of an empty string
@@ -1715,7 +1719,7 @@ public:
 
 
     //! returns the name of the service
-/** @return the name of the service
+    /** @return the name of the service
 
         @since %WSDL 0.5
     */
@@ -1723,14 +1727,14 @@ public:
 
 
     //! returns a unique hash for the WSDL that can be used to compare schemas for equality
-/** @return a unique hash for the WSDL that can be used to compare schemas for equality
+    /** @return a unique hash for the WSDL that can be used to compare schemas for equality
 
         @since %WSDL 0.5
     */
       synchronized string getHash();
 
     //! returns the given operation or throws an exception if it cannot be found; operations are searched in portTypes in the order they are declared
-/** @throw WSDL-OPERATION-ERROR if the operation is unknown
+    /** @throw WSDL-OPERATION-ERROR if the operation is unknown
     */
     WSDL::WSOperation getOperation(string opname);
 
@@ -1748,7 +1752,7 @@ public:
 
 
     //! returns a list of hashes giving supported operation names for each port in the WSDL
-/** @return a list of hashes giving supported operation names for each port in the WSDL; each hash<auto> has the following keys:
+    /** @return a list of hashes giving supported operation names for each port in the WSDL; each hash<auto> has the following keys:
         - \c "port": the name of the port defining the operation
         - \c "operation": the @ref WSDL::WSOperation object for the operation
      */
@@ -1756,7 +1760,7 @@ public:
 
 
     //! return a @ref WSDL::Binding object describing the requested binding
-/** @param name the name of the binding
+    /** @param name the name of the binding
 
         @return a @ref WSDL::Binding object
 
@@ -1766,7 +1770,7 @@ public:
 
 
     //! returns a list of services defined in the WSDL
-/** @return a list of hashes of services defined in the WSDL; each hash<auto> has the following keys:
+    /** @return a list of hashes of services defined in the WSDL; each hash<auto> has the following keys:
         - \c "name": the name of the service
         - \c "port": a hash of port information; the keys are port names and the values have the following keys:
           - \c "address": the location of the port
@@ -1776,7 +1780,7 @@ public:
 
 
     //! returns a hash describing the requested service
-/** @param name the name of the service
+    /** @param name the name of the service
         @return a hash describing the service with the following keys:
         - \c "name": the name of the service
         - \c "port": a hash of port information; where each hash<auto> is keyed by port name and the values have the following keys:
@@ -1854,25 +1858,25 @@ public:
 
 
     //! returns True if the WSDL describes a SOAP 1.2 service
-/** @return True if the WSDL describes a SOAP 1.2 service
+    /** @return True if the WSDL describes a SOAP 1.2 service
     */
     bool isSoap12();
 
 
     //! returns the XML string for the WSDL
-/** @return the XML string for the WSDL
+    /** @return the XML string for the WSDL
     */
     string getWSDL();
 
 
     //! returns a cryptographic hash for the WSDL source
-/** @return a cryptographic hash for the WSDL source
+    /** @return a cryptographic hash for the WSDL source
     */
     string getWSDLHash();
 
 
     //! returns the XML string for the WSDL, adjusting the URLs for binding locations depending on the caller
-/** @param base_url the url to be prepended before the service name;
+    /** @param base_url the url to be prepended before the service name;
                         it must include all the handler prefixes (like \c /SOAP)
                         to produce valid URL
         @return the XML string for the WSDL
@@ -1886,7 +1890,7 @@ public:
 
 
     //! prepare a WebService report enumerating the services and operations of the WSDL, outputs to the output stream given as the first argument
-/** @param stream the output stream for the report data
+    /** @param stream the output stream for the report data
         @param wsdl_name name of the WSDL, typically a file name
 
         @return human readable text report
@@ -1895,7 +1899,7 @@ public:
 
 
     //! prepare a WebService report enumerating the services and operations of the WSDL
-/** @param wsdl_name name of the WSDL, typically a file name
+    /** @param wsdl_name name of the WSDL, typically a file name
 
         @return human readable text report
     */
@@ -1903,7 +1907,7 @@ public:
 
 
     //! supports the constructor and deserialization
-/** @since %WSDL 0.4
+    /** @since %WSDL 0.4
     */
 private:
      doInit(string str, __7_ hash<auto> opts);
@@ -1911,7 +1915,7 @@ public:
 
 
     //! can be used to create a WebService object from a hash created with serialize()
-/** @return a WebService object from the argument hash created with serialize()
+    /** @return a WebService object from the argument hash created with serialize()
     */
 private:
      deserializeMembers(hash<auto> members);
@@ -1935,7 +1939,7 @@ public:
 
 
     //! creates the WebService object
-/** @param ws the object representing the WSDL
+    /** @param ws the object representing the WSDL
         @param opts an optional hash of options with the following possible keys:
         - \c "comments": (bool) generate comments as values with ^comment^ key, default: False
         - \c "choices": (bool) generate choices as sub hashes ^choices^ key, default: False
@@ -1963,7 +1967,7 @@ public:
 
 
     //! prepare sample message
-/** @param name message name
+    /** @param name message name
 
         @return a hash representing message
     */
@@ -1971,7 +1975,7 @@ public:
 
 
     //! prepare sample message
-/** @param msg WSMessage object
+    /** @param msg WSMessage object
 
         @return a hash representing message
     */
