@@ -33,27 +33,27 @@ protected:
 public:
 
     //! Creates the object with an empty logger and an in-memory property handler
-/** @param interfaces the WebDAV handlers to proxy
+    /** @param interfaces the WebDAV handlers to proxy
     */
     constructor(hash<string, AbstractWebDavHandler> interfaces);
 
 
     //! Creates the object with the given argument and an in-memory property handler
-/** @param interfaces the WebDAV handlers to proxy
+    /** @param interfaces the WebDAV handlers to proxy
         @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
-    constructor(hash<string, AbstractWebDavHandler> interfaces, string virtual_relative_path_base)
- ;
+    constructor(hash<string, AbstractWebDavHandler> interfaces, string virtual_relative_path_base) ;
 
 
     //! Creates the object with the given arguments
-/** @param interfaces the WebDAV handlers to proxy
+    /** @param interfaces the WebDAV handlers to proxy
         @param logger the logger
         @param virtual_relative_path_base the virtual base path for WebDavHandler requests; this path will be
         stripped from requests internally when serving WebDavHandler resources
     */
-constructor(hash<string, AbstractWebDavHandler> interfaces, Logger logger, string virtual_relative_path_base = '/') ;
+    constructor(hash<string, AbstractWebDavHandler> interfaces, Logger logger, string virtual_relative_path_base = "/")
+ ;
 
 
 protected:
@@ -66,7 +66,7 @@ protected:
 public:
 
 
-/**
+    /**
         GET
 
         Get a resource.
@@ -74,7 +74,7 @@ public:
     hash<HttpResponseInfo> handleGet(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         HEAD
 
         Same like GET but without sending a body.
@@ -82,7 +82,7 @@ public:
     hash<HttpResponseInfo> handleHead(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         POST
 
         Create new resource.
@@ -90,7 +90,7 @@ public:
     hash<HttpResponseInfo> handlePost(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         PUT
 
         Modify resource.
@@ -98,7 +98,7 @@ public:
     hash<HttpResponseInfo> handlePut(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         DELETE
 
         Delete a resource.
@@ -106,7 +106,7 @@ public:
     hash<HttpResponseInfo> handleDelete(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         COPY
 
         Copy a resource from one URI to another.
@@ -114,7 +114,7 @@ public:
     hash<HttpResponseInfo> handleCopy(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         MOVE
 
         Move a resource from one URI to another.
@@ -122,7 +122,7 @@ public:
     hash<HttpResponseInfo> handleMove(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         LOCK
 
         Put a lock on a resource. WebDavHandler supports both shared and exclusive locks.
@@ -130,7 +130,7 @@ public:
     hash<HttpResponseInfo> handleLock(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         UNLOCK
 
         Remove a lock from a resource.
@@ -138,7 +138,7 @@ public:
     hash<HttpResponseInfo> handleUnlock(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         MKCOL
 
         Create collections (aka a directory).
@@ -146,7 +146,7 @@ public:
     hash<HttpResponseInfo> handleMkcol(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         PROPFIND
 
         Retrieve properties, stored as XML, from a web resource. It is also
@@ -156,7 +156,7 @@ public:
     hash<HttpResponseInfo> handlePropfind(Socket sock, hash<auto> cx, hash<auto> hdr, __7_ data body);
 
 
-/**
+    /**
         PROPPATCH
 
         Change and delete multiple properties on a resource in a single atomic act.
