@@ -1,12 +1,12 @@
 var indexSectionsWithContent =
 {
-  0: "abcdefghilmnopqrstvx",
+  0: "012345678abcdefghilmnopqrstvx",
   1: "afimsx",
   2: "q",
   3: "abcdefghilmnoprstvx",
   4: "ehmnx",
-  5: "x",
-  6: "dq"
+  5: "cefgmnoprtx",
+  6: "dglmoqx"
 };
 
 var indexSectionNames =
