@@ -173,7 +173,7 @@ static QoreValue XmlNode_previousElementSibling(QoreObject* self, QoreXmlNodeDat
 }
 
 DLLLOCAL void preinitXmlNodeClass() {
-    QC_XMLNODE = new QoreClass("XmlNode", "::Qore::Xml::XmlNode", QDOM_DEFAULT);
+    QC_XMLNODE = new QoreBuiltinClass("XmlNode", "::Qore::Xml::XmlNode", QDOM_DEFAULT);
     CID_XMLNODE = QC_XMLNODE->getID();
     QC_XMLNODE->setSystem();
 }
